#
# spec file for package libcdata
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libcdata
%define lname	libcdata1
Version:        20240414
Release:        1.2
Summary:        Library for C generic data functions
License:        LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://github.com/libyal/libcdata
Source:         https://github.com/libyal/libcdata/releases/download/%version/libcdata-alpha-%version.tar.gz
Source2:        https://github.com/libyal/libcdata/releases/download/%version/libcdata-alpha-%version.tar.gz.asc
Source3:        %name.keyring
BuildRequires:  c_compiler
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(libcerror) >= 20240413
BuildRequires:  pkgconfig(libcthreads) >= 20240413
# Various notes: https://en.opensuse.org/libyal

%description
A library for C generic data functions.

This package is part of the libyal library collection and is used by other libraries in the collection

%package -n %lname
Summary:        Library for C generic data functions
Group:          System/Libraries

%description -n %lname
A library for C generic data functions.

This subpackage contains the actual shared object library

%package devel
Summary:        Development files for libcdata, a C generic data library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
A library for C generic data functions.

This subpackage contains libraries and header files for developing
applications that want to make use of libcdata.

%prep
%autosetup -p1

%build
# Enabling MTS in libcdata means data structures are protected by
# libcdata itself, with an implicit rwlock. Every downstream use
# (e.g. by libpff) suffers, even if libpff already made sure that any
# one libcdata object is not used concurrently. Therefore, we disable
# MTS. - https://github.com/libyal/libcdata/issues/6
echo "V_%version { global: *; };" >v.sym
%configure --disable-static --disable-multi-threading-support LDFLAGS="-Wl,--version-script=$PWD/v.sym"
grep '  local' config.log && exit 1
%make_build

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la

%ldconfig_scriptlets -n %lname

%files -n %lname
%license COPYING*
%_libdir/libcdata.so.1*

%files devel
%_includedir/libcdata*
%_libdir/libcdata.so
%_libdir/pkgconfig/libcdata.pc
%_mandir/man3/libcdata.3*

%changelog
* Sun Apr 14 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240414
  * No changelog was provided
* Wed Jan  3 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240103
  * No changelog was provided
* Sun Jan  8 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20230108
  * Updates to the linked list API
* Sat Nov 26 2022 Jan Engelhardt <jengelh@inai.de>
- Delete system-libs.patch (not needed - system libs are
  autodetected)
* Mon Aug  8 2022 Jan Engelhardt <jengelh@inai.de>
- Add forced symvers
* Sun Jan 16 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220115
  * Function libcdata_array_insert_entry sometimes returned a
    wrong entry index.
* Thu Nov 25 2021 Jan Engelhardt <jengelh@inai.de>
- Add keyring
* Mon Jul  5 2021 Jan Engelhardt <jengelh@inai.de>
- Disable implicit library-side locking during operations;
  performance for e.g. libpff improves by 190%%.
- Hard rerun autoreconf to workaround aclocal run failure
  in Leap.
* Sat Jun 26 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 20210625
  * No changelog was provided
* Wed May 12 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20210415 (2401fd5d)
  * No changelog was provided
- Add system-libs.patch
* Sun Dec 13 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20200509
  * No documented changes
* Tue Apr  2 2019 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20190112
  * fixed issue in libcdata_btree_node_get_sub_node_by_value
  * Changes to array to handle failure in lock release
  * Worked on B-tree type
  * API change in return value.  The change requires tests of the return value to be updated.
* Wed Feb 15 2017 Greg.Freemyer@gmail.com
- update to v0~20170102
  * worked on tests
- removed Requires libcstring
* Wed Jan 27 2016 Greg.Freemyer@gmail.com
- update to v0~20160108
  * added array remove entry function
  * 2016 update
  * updated dependencies
  * code clean up
  * corrections in include header
  * updated man page: libcdata.3
  * added libcdata_range_list_get_spanning_range
* Mon Jan  5 2015 Greg.Freemyer@gmail.com
- update to v0~20150101
  * 2015 update - minimal changes
- update URL to the new github site
- replace Source: field with fully defined URL
- remove DL-URL comment
- start using libcstring from OBS, not internal version
- add buildrequires for libcthreads
* Thu Aug 14 2014 Greg.Freemyer@gmail.com
- update to v0~20140105
  * updated dependencies
  * 2014 update
  * bug fix in array test
  * bug fix in list multi threading support
* Thu Oct  3 2013 Greg.Freemyer@gmail.com
- update to v0~20130904
  * added fail safe check in array
  * bug fix in array clone function
  * fix in .pc.in file
  * updated dependencies
  * bug fixes for recent changes
  * worked on multi-threading support
  * worked on tests
  * added libcthreads
  * updated msvscpp files
  * bug fix in range list
* Mon Jul 29 2013 Greg.Freemyer@gmail.com
- update to v0~20130407
  * small changes to range list
  * moved range list value to separate source files
  * added value support to range list
  * improved range list remove function to multiple ranges
  * textual updates
  * updated include header
  * added error functions
  * updated dependencies
  * added array prepend entry
  * added array reverse
  * 2013 update
- change from xz to gz to simplyfy download/convert step
* Mon Apr 22 2013 Greg.Freemyer@gmail.com
- run spec-cleaner
* Wed Apr  3 2013 jengelh@inai.de
- Initial package (version 0~20121224) for build.opensuse.org
